@@ -424,10 +424,7 @@ fn node_has_zero_opacity(node: &Node) -> bool {
 }
 
 fn get_text_width(text: &Text, font_db: &Database) -> Option<f64> {
-    let Some(node) = text.convert(font_db, Default::default()) else {
-        return None;
-    };
-    get_text_width_from_path(node)
+    get_text_width_from_path(text.convert(font_db, Default::default())?)
 }
 
 fn get_text_width_from_path(node: Node) -> Option<f64> {
