@@ -490,8 +490,10 @@ function vegaToScenegraph(vgSpec, allowedBaseUrls, formatLocale, timeFormatLocal
     return scenegraphPromise
 }
 "#;
-            self.worker
-                .execute_script("ext:<anon>", deno_core::FastString::Static(function_str))?;
+            self.worker.execute_script(
+                "ext:<anon>",
+                deno_core::FastString::from_static(function_str),
+            )?;
             self.worker.run_event_loop(false).await?;
 
             self.vega_initialized = true;
@@ -601,10 +603,7 @@ function vegaLiteToScenegraph_{ver_name}(vlSpec, config, theme, warnings, allowe
         script: &str,
     ) -> Result<serde_json::Value, AnyError> {
         let code = script.to_string();
-        let res = self
-            .worker
-            .js_runtime
-            .execute_script("ext:<anon>", code.into())?;
+        let res = self.worker.js_runtime.execute_script("ext:<anon>", code)?;
 
         self.worker.run_event_loop(false).await?;
 
@@ -624,10 +623,7 @@ function vegaLiteToScenegraph_{ver_name}(vlSpec, config, theme, warnings, allowe
 
     async fn execute_script_to_string(&mut self, script: &str) -> Result<String, AnyError> {
         let code = script.to_string();
-        let res = self
-            .worker
-            .js_runtime
-            .execute_script("ext:<anon>", code.into())?;
+        let res = self.worker.js_runtime.execute_script("ext:<anon>", code)?;
 
         self.worker.run_event_loop(false).await?;
 
